//   Copyright 2007, 2008 Nicolas Dubuit
//
//     This file is part of Immix.
//
//     Immix is free software: you can redistribute it and/or modify
//     it under the terms of the GNU General Public License as published by
//     the Free Software Foundation, either version 3 of the License, or
//     (at your option) any later version.
//
//     This program is distributed in the hope that it will be useful,
//     but WITHOUT ANY WARRANTY; without even the implied warranty of
//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//     GNU General Public License for more details.
//
//     You should have received a copy of the GNU General Public License
//     along with this program.  If not, see <http://www.gnu.org/licenses/>.

#include <QMainWindow>
#include <QMap>
#include <QString>
#include <QPointer>
#include <QImage>
#include <QStackedWidget>
#include <QSlider>
#include <QPushButton>
#include <QSpinBox>
#include <QLabel>

class ImmixDisplay ;
class AlignmentManager ;

class ImmixWin : public QStackedWidget
{
	Q_OBJECT
	QStackedWidget* stack ;	
	QSlider* slider ;
    QLabel* labFile ;
	QPushButton* btnAlign ;
	QPushButton* btnAverage ;
	QPushButton* btnRemove ;
	QPushButton* btnRevert ;
	QPushButton* btnQuit ;
	QSpinBox* spnMkr ;
	QSpinBox* spnFineFact ;
	QList< QPointer<ImmixDisplay> > displayList ;
	int activeIndex ;

    AlignmentManager* alignManager ;

	QPoint mkr1 ;
	QPoint mkr2 ;
	
	static int MkrSz ;
    static int FineFactor ;
	static int jpgQuality ;
	static float ZoomFactor ;
	static QString Suffix ;
	
public :
	ImmixWin (int& err, QWidget* parent = 0);

public slots :
	void StartAverage () ;
	void RemoveCurrent () ;
	void SwitchTo (int) ;
	void ChangeMarkerSize (int) ;
	void ChangeFineFactor (int) ;
	void Revert (void) ;
    void AddFile (const QString&) ;
    void SetFileList (const QStringList&) ;
 friend class ImmixDisplay ;
 friend class AlignmentManager ;
 friend class Aligner ;
} ;



class ImmixDisplay : public QWidget
{
	Q_OBJECT

	QPointer<ImmixWin> winPtr ;
	QImage* imgPtr ;
	QStringList filePath ;

	float currentZoomLevel ;
    static int margin ;

public :
	ImmixDisplay (ImmixWin* parent, QString fname) ;

public slots :
	void Load (void) ;
	void Unload (void) ;
	void ChangeFile (QString) ;
	void RevertFile (void) ;

protected :
	void paintEvent (QPaintEvent*) ;
	void mouseReleaseEvent ( QMouseEvent * ) ;

 friend class ImmixWin ;
 friend class AlignmentManager ;
 friend class Aligner ;

} ;

